@@ -268,7 +268,7 @@ evdev_inotify_process(int fd, uint32_t events)
   all_ie = (struct inotify_event *) malloc(qsize);
   if (all_ie == NULL)
     {
-      logmsg(LOG_ERR, "Could not allocate %d bytes for inotify events");
+      logmsg(LOG_ERR, "Could not allocate %d bytes for inotify events", qsize);
 
       return;
     }
@@ -766,6 +766,32 @@ evdev_is_extkbd_alu_wl(unsigned short *id)
   return 0;
 }
 
+/* Apple external wireless keyboard, aluminium, newer model */
+static int
+evdev_is_extkbd_alu_wl_2(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_BLUETOOTH)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_2_ANSI)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_2_ISO)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_ALU_WL_2_JIS))
+    {
+      logdebug(" -> External Apple wireless keyboard 2 (aluminium)\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
 /* Any external Apple USB keyboard */
 static int
 evdev_is_extkbd(unsigned short *id)
@@ -773,7 +799,8 @@ evdev_is_extkbd(unsigned short *id)
   return (evdev_is_extkbd_white(id)
 	  || evdev_is_extkbd_mini_alu(id)
 	  || evdev_is_extkbd_alu(id)
-	  || evdev_is_extkbd_alu_wl(id));
+	  || evdev_is_extkbd_alu_wl(id)
+	  || evdev_is_extkbd_alu_wl_2(id));
 }
 
 /* Mouseemu virtual keyboard */
