@@ -42,6 +42,7 @@ enum {
   SYSFS_DRIVER_NVIDIA,
 #else
   SYSFS_DRIVER_MBP,
+  SYSFS_DRIVER_NVIDIA,
 #endif
 };
 
@@ -59,6 +60,7 @@ static char *actual_brightness[] =
     "/sys/class/backlight/nvidiabl0/actual_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/actual_brightness",
+    "/sys/class/backlight/nvidia_backlight/actual_brightness",
 #endif
   };
 
@@ -72,6 +74,7 @@ static char *brightness[] =
     "/sys/class/backlight/nvidiabl0/brightness",
 #else
     "/sys/class/backlight/mbp_backlight/brightness",
+    "/sys/class/backlight/nvidia_backlight/brightness",
 #endif
   };
 
@@ -85,6 +88,7 @@ static char *max_brightness[] =
     "/sys/class/backlight/nvidiabl0/max_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/max_brightness",
+    "/sys/class/backlight/nvidia_backlight/max_brightness",
 #endif
   };
 
@@ -97,7 +101,7 @@ sysfs_backlight_get(void)
 {
   int fd;
   int n;
-  char buffer[4];
+  char buffer[8];
 
   if (bck_driver == SYSFS_DRIVER_NONE)
     return 0;
@@ -110,7 +114,8 @@ sysfs_backlight_get(void)
       return 0;
     }
 
-  n = read(fd, buffer, sizeof(buffer) -1);
+  memset(buffer, 0, sizeof(buffer));
+  n = read(fd, buffer, sizeof(buffer) - 1);
   if (n < 1)
     {
       logmsg(LOG_WARNING, "Could not read sysfs actual_brightness node");
@@ -128,7 +133,7 @@ sysfs_backlight_get_max(void)
 {
   int fd;
   int n;
-  char buffer[4];
+  char buffer[8];
 
   if (bck_driver == SYSFS_DRIVER_NONE)
     return 0;
@@ -141,7 +146,8 @@ sysfs_backlight_get_max(void)
       return 0;
     }
 
-  n = read(fd, buffer, sizeof(buffer) -1);
+  memset(buffer, 0, sizeof(buffer));
+  n = read(fd, buffer, sizeof(buffer) - 1);
   if (n < 1)
     {
       logmsg(LOG_WARNING, "Could not read sysfs max_brightness node");
@@ -393,6 +399,11 @@ mbp_sysfs_backlight_probe(void)
 
   ret = sysfs_backlight_probe(SYSFS_DRIVER_MBP);
 
+  if (ret == 0)
+    return 0;
+
+  ret = sysfs_backlight_probe(SYSFS_DRIVER_NVIDIA);
+
   if (ret == 0)
     return 0;
 
